setwd("~/Feng_He_project/SysTACT_allergy_study/limma_withXY_all_modelA/DEG_combined_ranking")

load("~/Feng_He_project/SysTACT_allergy_study/limma_withXY_all_modelA/workspace_limma.RData")

calcRank_increasing <- function(x){
  sorted <- x[order(x)]
  ranks <- sapply(x, function(x) min(which(sorted==x)))
  return(ranks)
}

calcRank_decreasing <- function(x){
  sorted <- x[order(x,decreasing = TRUE)]
  ranks <- sapply(x, function(x) min(which(sorted==x)))
  return(ranks)
}

#Pollen T3 versus pollen T0 (42d)
DEGs_pollen_T3_vs_pollen_T0<-table_PollenT3vsPollenT0[which(table_PollenT3vsPollenT0$adj.P.Val<=0.05),]
DEGs_control_T5_vs_control_T0<-table_ControlT3vsControlT0[which(table_ControlT3vsControlT0$adj.P.Val<=0.05),]
indices<-which(rownames(DEGs_pollen_T3_vs_pollen_T0) %in% rownames(DEGs_control_T5_vs_control_T0))
DEGs_pollen_T3_vs_pollen_T0<-DEGs_pollen_T3_vs_pollen_T0[-indices,]

fdr<-DEGs_pollen_T3_vs_pollen_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_pollen_T3_vs_pollen_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_pollen_T3_vs_pollen_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_pollen_T3_vs_pollen_T0)[i])
}
col_indices<-which(phenotype=="P" & time=="42")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_pollen_T3_vs_pollen_T0<-data.frame(gene_ID=rownames(DEGs_pollen_T3_vs_pollen_T0),
                                               gene_name=DEGs_pollen_T3_vs_pollen_T0$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_pollen_T3_vs_pollen_T0<-ranked_DEGs_pollen_T3_vs_pollen_T0[order(ranked_DEGs_pollen_T3_vs_pollen_T0$combined_rank),]
write.table(ranked_DEGs_pollen_T3_vs_pollen_T0,
            file="ranked_DEGs_pollen_T3_vs_pollen_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Pollen T4 versus pollen T0 (84d)
DEGs_pollen_T4_vs_pollen_T0<-table_PollenT4vsPollenT0[which(table_PollenT4vsPollenT0$adj.P.Val<=0.05),]

fdr<-DEGs_pollen_T4_vs_pollen_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_pollen_T4_vs_pollen_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_pollen_T4_vs_pollen_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_pollen_T4_vs_pollen_T0)[i])
}
col_indices<-which(phenotype=="P" & time=="84")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_pollen_T4_vs_pollen_T0<-data.frame(gene_ID=rownames(DEGs_pollen_T4_vs_pollen_T0),
                                               gene_name=DEGs_pollen_T4_vs_pollen_T0$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_pollen_T4_vs_pollen_T0<-ranked_DEGs_pollen_T4_vs_pollen_T0[order(ranked_DEGs_pollen_T4_vs_pollen_T0$combined_rank),]
write.table(ranked_DEGs_pollen_T4_vs_pollen_T0,
            file="ranked_DEGs_pollen_T4_vs_pollen_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T1 versus venom T0
DEGs_venom_T1_vs_venom_T0<-table_VenomT1vsVenomT0[which(table_VenomT1vsVenomT0$adj.P.Val<=0.05),]
DEGs_control_T1_vs_control_T0<-table_ControlT1vsControlT0[which(table_ControlT1vsControlT0$adj.P.Val<=0.05),]
indices<-which(rownames(DEGs_venom_T1_vs_venom_T0) %in% rownames(DEGs_control_T1_vs_control_T0))
DEGs_venom_T1_vs_venom_T0<-DEGs_venom_T1_vs_venom_T0[-indices,]

fdr<-DEGs_venom_T1_vs_venom_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_venom_T1_vs_venom_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_venom_T1_vs_venom_T0)[1]
row_indices<-vector(mode='integer',length=d)
#PUT A LOOP EVERYWHERE INSTEAD OF USING "IN"
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_venom_T1_vs_venom_T0)[i])
}
col_indices<-which(phenotype=="V" & time=="0.3")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_venom_T1_vs_venom_T0<-data.frame(gene_ID=rownames(DEGs_venom_T1_vs_venom_T0),
                                               gene_name=DEGs_venom_T1_vs_venom_T0$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_venom_T1_vs_venom_T0<-ranked_DEGs_venom_T1_vs_venom_T0[order(ranked_DEGs_venom_T1_vs_venom_T0$combined_rank),]
write.table(ranked_DEGs_venom_T1_vs_venom_T0,
            file="ranked_DEGs_venom_T1_vs_venom_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T2 versus venom T0
DEGs_venom_T2_vs_venom_T0<-table_VenomT2vsVenomT0[which(table_VenomT2vsVenomT0$adj.P.Val<=0.05),]

fdr<-DEGs_venom_T2_vs_venom_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_venom_T2_vs_venom_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_venom_T2_vs_venom_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_venom_T2_vs_venom_T0)[i])
}
col_indices<-which(phenotype=="V" & time=="1")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_venom_T2_vs_venom_T0<-data.frame(gene_ID=rownames(DEGs_venom_T2_vs_venom_T0),
                                             gene_name=DEGs_venom_T2_vs_venom_T0$gene_symbol,
                                             fdr=fdr,
                                             rank_fdr=rank_fdr,
                                             abs_logFC=abs_logFC,
                                             rank_abs_logFC=rank_abs_logFC,
                                             av_log_expr=av_log_expr,
                                             rank_av_log_expr=rank_av_log_expr,
                                             sum_of_ranks=sum_of_ranks,
                                             combined_rank=combined_rank)
ranked_DEGs_venom_T2_vs_venom_T0<-ranked_DEGs_venom_T2_vs_venom_T0[order(ranked_DEGs_venom_T2_vs_venom_T0$combined_rank),]
write.table(ranked_DEGs_venom_T2_vs_venom_T0,
            file="ranked_DEGs_venom_T2_vs_venom_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T3 versus venom T0
DEGs_venom_T3_vs_venom_T0<-table_VenomT3vsVenomT0[which(table_VenomT3vsVenomT0$adj.P.Val<=0.05),]
DEGs_control_T3_vs_control_T0<-table_ControlT3vsControlT0[which(table_ControlT3vsControlT0$adj.P.Val<=0.05),]
indices<-which(rownames(DEGs_venom_T3_vs_venom_T0) %in% rownames(DEGs_control_T3_vs_control_T0))
DEGs_venom_T3_vs_venom_T0<-DEGs_venom_T3_vs_venom_T0[-indices,]

fdr<-DEGs_venom_T3_vs_venom_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_venom_T3_vs_venom_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_venom_T3_vs_venom_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_venom_T3_vs_venom_T0)[i])
}
col_indices<-which(phenotype=="V" & time=="7")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_venom_T3_vs_venom_T0<-data.frame(gene_ID=rownames(DEGs_venom_T3_vs_venom_T0),
                                             gene_name=DEGs_venom_T3_vs_venom_T0$gene_symbol,
                                             fdr=fdr,
                                             rank_fdr=rank_fdr,
                                             abs_logFC=abs_logFC,
                                             rank_abs_logFC=rank_abs_logFC,
                                             av_log_expr=av_log_expr,
                                             rank_av_log_expr=rank_av_log_expr,
                                             sum_of_ranks=sum_of_ranks,
                                             combined_rank=combined_rank)
ranked_DEGs_venom_T3_vs_venom_T0<-ranked_DEGs_venom_T3_vs_venom_T0[order(ranked_DEGs_venom_T3_vs_venom_T0$combined_rank),]
write.table(ranked_DEGs_venom_T3_vs_venom_T0,
            file="ranked_DEGs_venom_T3_vs_venom_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Pollen T0 versus ctrl T0
DEGs_Pollen_T0_vs_Control_T0<-table_PollenT0vsControlT0[which(table_PollenT0vsControlT0$adj.P.Val<=0.05),]

fdr<-DEGs_Pollen_T0_vs_Control_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Pollen_T0_vs_Control_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Pollen_T0_vs_Control_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Pollen_T0_vs_Control_T0)[i])
}
col_indices<-which(phenotype=="P" & time=="0")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Pollen_T0_vs_Control_T0<-data.frame(gene_ID=rownames(DEGs_Pollen_T0_vs_Control_T0),
                                             gene_name=DEGs_Pollen_T0_vs_Control_T0$gene_symbol,
                                             fdr=fdr,
                                             rank_fdr=rank_fdr,
                                             abs_logFC=abs_logFC,
                                             rank_abs_logFC=rank_abs_logFC,
                                             av_log_expr=av_log_expr,
                                             rank_av_log_expr=rank_av_log_expr,
                                             sum_of_ranks=sum_of_ranks,
                                             combined_rank=combined_rank)
ranked_DEGs_Pollen_T0_vs_Control_T0<-ranked_DEGs_Pollen_T0_vs_Control_T0[order(ranked_DEGs_Pollen_T0_vs_Control_T0$combined_rank),]
write.table(ranked_DEGs_Pollen_T0_vs_Control_T0,
            file="ranked_DEGs_Pollen_T0_vs_Control_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Pollen T1 versus ctrl T1
DEGs_Pollen_T1_vs_Control_T1<-table_PollenT1vsControlT1[which(table_PollenT1vsControlT1$adj.P.Val<=0.05),]

fdr<-DEGs_Pollen_T1_vs_Control_T1$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Pollen_T1_vs_Control_T1$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Pollen_T1_vs_Control_T1)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Pollen_T1_vs_Control_T1)[i])
}
col_indices<-which(phenotype=="P" & time=="1")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Pollen_T1_vs_Control_T1<-data.frame(gene_ID=rownames(DEGs_Pollen_T1_vs_Control_T1),
                                                gene_name=DEGs_Pollen_T1_vs_Control_T1$gene_symbol,
                                                fdr=fdr,
                                                rank_fdr=rank_fdr,
                                                abs_logFC=abs_logFC,
                                                rank_abs_logFC=rank_abs_logFC,
                                                av_log_expr=av_log_expr,
                                                rank_av_log_expr=rank_av_log_expr,
                                                sum_of_ranks=sum_of_ranks,
                                                combined_rank=combined_rank)
ranked_DEGs_Pollen_T1_vs_Control_T1<-ranked_DEGs_Pollen_T1_vs_Control_T1[order(ranked_DEGs_Pollen_T1_vs_Control_T1$combined_rank),]
write.table(ranked_DEGs_Pollen_T1_vs_Control_T1,
            file="ranked_DEGs_Pollen_T1_vs_Control_T1.txt",
            row.names = FALSE,col.names = TRUE)

#Pollen T2 versus ctrl T2
DEGs_Pollen_T2_vs_Control_T2<-table_PollenT2vsControlT2[which(table_PollenT2vsControlT2$adj.P.Val<=0.05),]

fdr<-DEGs_Pollen_T2_vs_Control_T2$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Pollen_T2_vs_Control_T2$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Pollen_T2_vs_Control_T2)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Pollen_T2_vs_Control_T2)[i])
}
col_indices<-which(phenotype=="P" & time=="14")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Pollen_T2_vs_Control_T2<-data.frame(gene_ID=rownames(DEGs_Pollen_T2_vs_Control_T2),
                                                gene_name=DEGs_Pollen_T2_vs_Control_T2$gene_symbol,
                                                fdr=fdr,
                                                rank_fdr=rank_fdr,
                                                abs_logFC=abs_logFC,
                                                rank_abs_logFC=rank_abs_logFC,
                                                av_log_expr=av_log_expr,
                                                rank_av_log_expr=rank_av_log_expr,
                                                sum_of_ranks=sum_of_ranks,
                                                combined_rank=combined_rank)
ranked_DEGs_Pollen_T2_vs_Control_T2<-ranked_DEGs_Pollen_T2_vs_Control_T2[order(ranked_DEGs_Pollen_T2_vs_Control_T2$combined_rank),]
write.table(ranked_DEGs_Pollen_T2_vs_Control_T2,
            file="ranked_DEGs_Pollen_T2_vs_Control_T2.txt",
            row.names = FALSE,col.names = TRUE)

#Pollen T4 versus ctrl T4
DEGs_Pollen_T4_vs_Control_T4<-table_PollenT4vsControlT4[which(table_PollenT4vsControlT4$adj.P.Val<=0.05),]

fdr<-DEGs_Pollen_T4_vs_Control_T4$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Pollen_T4_vs_Control_T4$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Pollen_T4_vs_Control_T4)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Pollen_T4_vs_Control_T4)[i])
}
col_indices<-which(phenotype=="P" & time=="84")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Pollen_T4_vs_Control_T4<-data.frame(gene_ID=rownames(DEGs_Pollen_T4_vs_Control_T4),
                                                gene_name=DEGs_Pollen_T4_vs_Control_T4$gene_symbol,
                                                fdr=fdr,
                                                rank_fdr=rank_fdr,
                                                abs_logFC=abs_logFC,
                                                rank_abs_logFC=rank_abs_logFC,
                                                av_log_expr=av_log_expr,
                                                rank_av_log_expr=rank_av_log_expr,
                                                sum_of_ranks=sum_of_ranks,
                                                combined_rank=combined_rank)
ranked_DEGs_Pollen_T4_vs_Control_T4<-ranked_DEGs_Pollen_T4_vs_Control_T4[order(ranked_DEGs_Pollen_T4_vs_Control_T4$combined_rank),]
write.table(ranked_DEGs_Pollen_T4_vs_Control_T4,
            file="ranked_DEGs_Pollen_T4_vs_Control_T4.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T0 versus ctrl T0
DEGs_Venom_T0_vs_Control_T0<-table_VenomT0vsControlT0[which(table_VenomT0vsControlT0$adj.P.Val<=0.05),]

fdr<-DEGs_Venom_T0_vs_Control_T0$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Venom_T0_vs_Control_T0$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Venom_T0_vs_Control_T0)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Venom_T0_vs_Control_T0)[i])
}
col_indices<-which(phenotype=="V" & time=="0")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Venom_T0_vs_Control_T0<-data.frame(gene_ID=rownames(DEGs_Venom_T0_vs_Control_T0),
                                                gene_name=DEGs_Venom_T0_vs_Control_T0$gene_symbol,
                                                fdr=fdr,
                                                rank_fdr=rank_fdr,
                                                abs_logFC=abs_logFC,
                                                rank_abs_logFC=rank_abs_logFC,
                                                av_log_expr=av_log_expr,
                                                rank_av_log_expr=rank_av_log_expr,
                                                sum_of_ranks=sum_of_ranks,
                                                combined_rank=combined_rank)
ranked_DEGs_Venom_T0_vs_Control_T0<-ranked_DEGs_Venom_T0_vs_Control_T0[order(ranked_DEGs_Venom_T0_vs_Control_T0$combined_rank),]
write.table(ranked_DEGs_Venom_T0_vs_Control_T0,
            file="ranked_DEGs_Venom_T0_vs_Control_T0.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T1 versus ctrl T1
DEGs_Venom_T1_vs_Control_T1<-table_VenomT1vsControlT1[which(table_VenomT1vsControlT1$adj.P.Val<=0.05),]

fdr<-DEGs_Venom_T1_vs_Control_T1$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Venom_T1_vs_Control_T1$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Venom_T1_vs_Control_T1)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Venom_T1_vs_Control_T1)[i])
}
col_indices<-which(phenotype=="V" & time=="0.3")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Venom_T1_vs_Control_T1<-data.frame(gene_ID=rownames(DEGs_Venom_T1_vs_Control_T1),
                                               gene_name=DEGs_Venom_T1_vs_Control_T1$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_Venom_T1_vs_Control_T1<-ranked_DEGs_Venom_T1_vs_Control_T1[order(ranked_DEGs_Venom_T1_vs_Control_T1$combined_rank),]
write.table(ranked_DEGs_Venom_T1_vs_Control_T1,
            file="ranked_DEGs_Venom_T1_vs_Control_T1.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T2 versus ctrl T2
DEGs_Venom_T2_vs_Control_T2<-table_VenomT2vsControlT2[which(table_VenomT2vsControlT2$adj.P.Val<=0.05),]

fdr<-DEGs_Venom_T2_vs_Control_T2$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Venom_T2_vs_Control_T2$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Venom_T2_vs_Control_T2)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Venom_T2_vs_Control_T2)[i])
}
col_indices<-which(phenotype=="V" & time=="1")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Venom_T2_vs_Control_T2<-data.frame(gene_ID=rownames(DEGs_Venom_T2_vs_Control_T2),
                                               gene_name=DEGs_Venom_T2_vs_Control_T2$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_Venom_T2_vs_Control_T2<-ranked_DEGs_Venom_T2_vs_Control_T2[order(ranked_DEGs_Venom_T2_vs_Control_T2$combined_rank),]
write.table(ranked_DEGs_Venom_T2_vs_Control_T2,
            file="ranked_DEGs_Venom_T2_vs_Control_T2.txt",
            row.names = FALSE,col.names = TRUE)

#Venom T3 versus ctrl T3
DEGs_Venom_T3_vs_Control_T3<-table_VenomT3vsControlT3[which(table_VenomT3vsControlT3$adj.P.Val<=0.05),]

fdr<-DEGs_Venom_T3_vs_Control_T3$adj.P.Val
rank_fdr<-calcRank_increasing(fdr)

abs_logFC<-abs(DEGs_Venom_T3_vs_Control_T3$logFC)
rank_abs_logFC<-calcRank_decreasing(abs_logFC)

d<-dim(DEGs_Venom_T3_vs_Control_T3)[1]
row_indices<-vector(mode='integer',length=d)
for (i in 1:d){
  row_indices[i]<-which(rownames(data)==rownames(DEGs_Venom_T3_vs_Control_T3)[i])
}
col_indices<-which(phenotype=="V" & time=="7")
data_sel<-data[row_indices,col_indices]
av_log_expr<-as.numeric(rowMeans(data_sel))
rank_av_log_expr<-calcRank_decreasing(av_log_expr)

sum_of_ranks<-rank_fdr + rank_abs_logFC + rank_av_log_expr
combined_rank<-calcRank_increasing(sum_of_ranks)

ranked_DEGs_Venom_T3_vs_Control_T3<-data.frame(gene_ID=rownames(DEGs_Venom_T3_vs_Control_T3),
                                               gene_name=DEGs_Venom_T3_vs_Control_T3$gene_symbol,
                                               fdr=fdr,
                                               rank_fdr=rank_fdr,
                                               abs_logFC=abs_logFC,
                                               rank_abs_logFC=rank_abs_logFC,
                                               av_log_expr=av_log_expr,
                                               rank_av_log_expr=rank_av_log_expr,
                                               sum_of_ranks=sum_of_ranks,
                                               combined_rank=combined_rank)
ranked_DEGs_Venom_T3_vs_Control_T3<-ranked_DEGs_Venom_T3_vs_Control_T3[order(ranked_DEGs_Venom_T3_vs_Control_T3$combined_rank),]
write.table(ranked_DEGs_Venom_T3_vs_Control_T3,
            file="ranked_DEGs_Venom_T3_vs_Control_T3.txt",
            row.names = FALSE,col.names = TRUE)