
# Analysis Scripts for SysTACT

# Table of contents
* [Introduction](#introduction)
* [Content](#content)
* [Requirements](#requirements)
* [License](#license)
* [Instructions](#instructions)

# Introduction
This repository contains the code for analyses performed for the SysTACT project. The scripts are organized into different directories based on their specific functions and analysis types.

# Content
The repository includes the following directories and their respective scripts:

1. **DEG_combined_ranking**
   - `DEG_combined_ranking.R`: Script for combining and ranking differentially expressed genes.

2. **QC**
   - Contains quality control scripts.

3. **batch_effects**
   - Scripts related to the analysis and correction of batch effects.

4. **boxplots_DEGs**
   - Scripts for generating boxplots of differentially expressed genes.

5. **confounders**
   - Scripts for analyzing potential confounding factors.

6. **exon_level_analysis**
   - `limma_exon.R`: Script for exon-level analysis using the limma package.
   
7. **heat_maps**
   - `heatmaps.R`: Script for generating heat maps.

8. **limma**
   - `limma_venom_pollen.R`, `select_high_expressed.R`, `limma.R`: Scripts for differential expression analysis using the limma package.

9. **limma_females_only**
   - Contains scripts for limma analysis specific to female samples.

10. **limma_withoutXY**
    - Scripts for limma analysis excluding XY chromosomes.

11. **limma_without_gender_correction**
    - Scripts for limma analysis without gender correction.

12. **outlier_detection**
    - Contains scripts for detecting outliers in the dataset.

13. **paper_mouse_DEG_to_compare**
    - Scripts for comparing differentially expressed genes in mouse models.

14. **read_summarization**
    - Contains scripts for summarizing read data.

15. **read_summarization_exon**
    - Scripts specific to exon read summarization.

16. **support_vector_machines**
    - `boxplots_top10_svm.R`, `lin_svm.R`: Scripts for analysis using support vector machines.

17. **trend_analysis_STEM**
    - Contains scripts for trend analysis using STEM.
    - `settings_venom_control`, `settings_pollen_control`: Configuration files for trend analysis.
    - `input_STEM_venom_control.R`, `input_STEM_pollen_control.R`: Input files for STEM analysis.

18. **trend_analysis_STEM_v2**
    - Updated scripts for trend analysis using STEM.
    - `settings_venom_control`, `settings_pollen_control`: Configuration files for trend analysis.
    - `input_STEM_venom_control_2`, `input_STEM_pollen_control_2`: Updated input files for STEM analysis.

19. **volcano_plots**
    - `volcano_plots.R`: Script for generating volcano plots.

# Requirements
The code was written entirely in R. It relies on multiple R and Bioconductor packages, listed at the beginning of the corresponding R scripts.

# License
The code is available under the MIT License.

# Instructions
The code was tested to run in R4.2.0 on both current Mac (Ventura) and Linux operating systems (Ubuntu 23.04), but should be compatible with later versions of R installed on current Mac, Linux or Windows systems.
R software packages loaded at the beginning of the R scripts must be installed before using the code. R packages available on CRAN can be installed with the command:

\`\`\`R
install.packages("ADD_NAME_OF_THE_PACKAGE")
\`\`\`

R packages from Bioconductor can be installed with the following commands:

\`\`\`R
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("ADD_NAME_OF_THE_PACKAGE")
\`\`\`

To run the code, the correct working directory containing the input data must be specified at the beginning of the R-scripts, otherwise the scripts can be run as-is.
