setwd("~/Feng_He_project/SysTACT_allergy_study/batch_effects_v2")
load("~/Feng_He_project/SysTACT_allergy_study/read_summarization_v2/counts.RData")
counts<-fc$counts

##########################
# Create a DGElist object
##########################
library("edgeR")
dge <- DGEList(counts=fc$counts)

##############################
# Make the targets and design
##############################
library(limma)
metadata<-strsplit2(colnames(counts),split="[.]")
metadata<-strsplit2(metadata[,9],split="_")
group<-vector(mode="character",length=188)
time_points<-vector(mode="character",length=188)
person<-vector(mode="character",length=188)
for (i in 1:188){
  group[i]<-substr(metadata[i,2],1,1)
  person[i]<-substr(metadata[i,2],1,3)
  time_points[i]<-substr(metadata[i,2],4,5)
}

time<-vector(mode="numeric",length=188)
time[which(time_points=="T0")]=0

time[which(group=="V" & time_points=="T1")]=0.3
time[which(group=="V" & time_points=="T2")]=1
time[which(group=="V" & time_points=="T3")]=7

time[which(group=="P" & time_points=="T1")]=1
time[which(group=="P" & time_points=="T2")]=14
time[which(group=="P" & time_points=="T3")]=42
time[which(group=="P" & time_points=="T4")]=84

time[which(group=="C" & time_points=="T1")]=0.3
time[which(group=="C" & time_points=="T2")]=1
time[which(group=="C" & time_points=="T3")]=7
time[which(group=="C" & time_points=="T4")]=14
time[which(group=="C" & time_points=="T5")]=42
time[which(group=="C" & time_points=="T6")]=84

metadata<-cbind(metadata[,1],metadata[,2],group,time_points,time,person)

colnames(metadata)[1:2]=c("batch","sample")

library(readxl)

X2019_07_19_SYS_T_Act_patient_demographics <- read_excel("~/Feng_He_project/SysTACT_allergy_study/confounders/2019.07.19 SYS-T-Act patient demographics.xlsx")
#remove persons without RNAseq samples, there are:
#V01,V02,V03,P05,P07
indices<-which(X2019_07_19_SYS_T_Act_patient_demographics$`SYS T ACT ID` %in% c("V01","V02","V03","P05","P07"))

covariate_table<-X2019_07_19_SYS_T_Act_patient_demographics[-indices,]
group<-vector(mode="character",length=39)
group[1:15]="venom"
group[16:29]="pollen"
group[30:39]="control"
covariate_table<-cbind(covariate_table,group)

age<-vector(mode="numeric",length=188)
bmi<-vector(mode="numeric",length=188)
ethnicity<-vector(mode="character",length=188)
smoking<-vector(mode="character",length=188)
culprit<-vector(mode="character",length=188)
gender<-vector(mode="character",length=188)

for (i in 1:188){
  age[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Age
  bmi[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$BMI
  ethnicity[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Ethnicity
  smoking[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Smoking
  culprit[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$`Culprit allergen`
  gender[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Sex
}

metadata<-cbind(metadata,age,bmi,ethnicity,smoking,culprit,gender)

Filename<-as.character(colnames(counts))
phenotype<-metadata[,3]
targets<-data.frame(Filename=Filename,phenotype=phenotype,
                    age=age,gender=gender,smoking=smoking,
                    time=time,person=person)
write.table(targets, file="targets.txt", sep = ",",row.names = FALSE)
design<-model.matrix(~0+targets$phenotype+targets$age+targets$gender
                     +targets$smoking+targets$time)
colnames(design)<-strsplit2(colnames(design),split="[$]")[,2]

############################################################
# Remove rows that consistently have zero or very low counts
############################################################
keep <- filterByExpr(dge, design) 
dge <- dge[keep,,keep.lib.sizes=FALSE]

#############################
# TMM normalization
#############################
dge <- calcNormFactors(dge)

#############################
# Voom transform
#############################
v <- voom(dge, design, plot=TRUE)

#############################
# check batch effects
#############################
batch<-metadata[,1]
library(ggplot2)
library(ggfortify)
df<-data.frame(t(v$E),batch=batch)
autoplot(prcomp(df[1:18345]),data=df,colour='batch')

