library(readxl)

X2019_07_19_SYS_T_Act_patient_demographics <- read_excel("Feng_He_project/SysTACT_allergy_study/2019.07.19 SYS-T-Act patient demographics.xlsx")

#remove persons without RNAseq samples, there are:
#V01,V02,V03,P05,P07
indices<-which(X2019_07_19_SYS_T_Act_patient_demographics$`SYS T ACT ID` %in% c("V01","V02","V03","P05","P07"))

covariate_table<-X2019_07_19_SYS_T_Act_patient_demographics[-indices,]
group<-vector(mode="character",length=39)
group[1:15]="venom"
group[16:29]="pollen"
group[30:39]="control"
covariate_table<-cbind(covariate_table,group)

###########################
## one-way ANOVA for age ##
###########################
age.aov<-aov(Age ~ group,data=covariate_table)
summary(age.aov)
#             Df Sum Sq Mean Sq F value  Pr(>F)   
# group        2   1252   625.8   6.322 0.00444 **
# Residuals   36   3563    99.0                   
# ---

TukeyHSD(age.aov)
#                   diff       lwr      upr     p adj
# pollen-control  1.857143  -8.211699 11.92599 0.8943461
# venom-control   12.633333  2.705321 22.56135 0.0099524
# venom-pollen    10.776190  1.739128 19.81325 0.0163711
# The average age is significantly different between groups, so has to be considered as confounder

library(dplyr)
group_by(covariate_table, group) %>%
  summarise(
    count = n(),
    mean = mean(Age, na.rm = TRUE),
    sd = sd(Age, na.rm = TRUE)
  )
# # A tibble: 3 x 4
#   group   count  mean    sd
#   <fct>   <int> <dbl> <dbl>
# 1 control    10  35.5  7.63
# 2 pollen     14  37.4  6.88
# 3 venom      15  48.1 13.2 

# 1. Homogeneity of variances
plot(age.aov, 1)
# points 1,2 and 11 are detected as outliers
# Levene's test
library(car)
leveneTest(Age ~ group,data=covariate_table)
# Levene's Test for Homogeneity of Variance (center = median)
#       Df F value  Pr(>F)  
# group  2  4.7529 0.01473 *
# 36                  
# ---
# The p-value is less than 0.05. This means that the variance across groups is statistically different.

# 2. Normality
plot(age.aov, 2)
#As all the points fall approximately along this reference line, we can assume normality.

# ANOVA test with no assumption of equal variances - Welch one-way test
oneway.test(Age ~ group,data=covariate_table)
# One-way analysis of means (not assuming equal variances)
# 
# data:  Age and group
# F = 4.8396, num df = 2.000, denom df = 22.131, p-value = 0.01805
# Significant => confounder

#  Kruskal-Wallis rank sum test (non-parametric alternative to one-way ANOVA when assumptions are not met)
kruskal.test(Age ~ group,data=covariate_table)
# Kruskal-Wallis rank sum test
# 
# data:  Age by group
# Kruskal-Wallis chi-squared = 8.1992, df = 2, p-value = 0.01658
# significant => confounder

###########################
## one-way ANOVA for bmi ##
###########################
bmi.aov<-aov(BMI ~ group,data=covariate_table)
summary(bmi.aov)
#             Df Sum Sq Mean Sq F value Pr(>F)
# group        2    121   60.48   1.239  0.302
# Residuals   36   1756   48.79
TukeyHSD(bmi.aov)
#                 diff       lwr       upr     p adj
# pollen-control 2.741001 -4.328075  9.810077 0.6140883
# venom-control  4.489437 -2.480766 11.459640 0.2696043
# venom-pollen   1.748436 -4.596254  8.093126 0.7802185
# The average BMI is not significantly different between groups, so doesn't have to be considered as a confounder


library(dplyr)
group_by(covariate_table, group) %>%
  summarise(
    count = n(),
    mean = mean(BMI, na.rm = TRUE),
    sd = sd(BMI, na.rm = TRUE)
  )
# # A tibble: 3 x 4
#   group   count  mean    sd
#   <fct>   <int> <dbl> <dbl>
# 1 control    10  22.7  1.94
# 2 pollen     14  25.4  7.23
# 3 venom      15  27.1  8.63

# 1. Homogeneity of variances
plot(bmi.aov, 1)
# points 4, 10 and 16 are detected as outliers
leveneTest(BMI ~ group,data=covariate_table)
# Levene's Test for Homogeneity of Variance (center = median)
#       Df F value Pr(>F)
# group  2   1.043 0.3628
# 36 
# The p-value is not less than 0.05. This means that there is no evidence that the variance across groups is statistically different.

# 2. Normality
plot(bmi.aov, 2)
#Points 10 and 16 deviate from the line => we cannot assume normality

# ANOVA test with no assumption of equal variances - Welch one-way test
oneway.test(BMI ~ group,data=covariate_table)
# One-way analysis of means (not assuming equal variances)
# 
# data:  BMI and group
# F = 2.5233, num df = 2.000, denom df = 20.625, p-value = 0.1046
# Not significant => no confounder

#  Kruskal-Wallis rank sum test (non-parametric alternative to one-way ANOVA when assumptions are not met)
kruskal.test(BMI ~ group,data=covariate_table)
# Kruskal-Wallis rank sum test
# 
# data:  BMI by group
# Kruskal-Wallis chi-squared = 1.9582, df = 2, p-value = 0.3757
# not significant => no confounder

################################
# Fisher exact test for gender #
################################
a<-length(which(covariate_table$Sex=="m" & covariate_table$group=="venom"))
b<-length(which(covariate_table$Sex=="m" & covariate_table$group=="pollen"))
c<-length(which(covariate_table$Sex=="m" & covariate_table$group=="control"))
d<-length(which(covariate_table$Sex=="f" & covariate_table$group=="venom"))
e<-length(which(covariate_table$Sex=="f" & covariate_table$group=="pollen"))
f<-length(which(covariate_table$Sex=="f" & covariate_table$group=="control"))

Gender<-rbind(c(a,d),c(b,e),c(c,f))
fisher.test(Gender)
# Fisher's Exact Test for Count Data
# 
# data:  Gender
# p-value = 0.01897
# alternative hypothesis: two.sided
# Gender is significantly different among groups

########################################
# Fisher exact test for smoking status #
########################################
a1<-length(which(covariate_table$Smoking=="Yes" & covariate_table$group=="venom"))
a2<-length(which(covariate_table$Smoking=="Yes" & covariate_table$group=="pollen"))
a3<-length(which(covariate_table$Smoking=="Yes" & covariate_table$group=="control"))
b1<-length(which(covariate_table$Smoking=="No" & covariate_table$group=="venom"))
b2<-length(which(covariate_table$Smoking=="No" & covariate_table$group=="pollen"))
b3<-length(which(covariate_table$Smoking=="No" & covariate_table$group=="control"))
c1<-length(which(covariate_table$Smoking=="I quit" & covariate_table$group=="venom"))
c2<-length(which(covariate_table$Smoking=="I quit" & covariate_table$group=="pollen"))
c3<-length(which(covariate_table$Smoking=="I quit" & covariate_table$group=="control"))

Smoking<-rbind(c(a1,b1,c1),c(a2,b2,c2),c(a3,b3,c3))
fisher.test(Smoking)
# Fisher's Exact Test for Count Data
# 
# data:  Smoking
# p-value = 0.001003
# alternative hypothesis: two.sided
# Smoking is significantly different among groups

###################################
# Fisher exact test for ethnicity #
###################################
d1<-length(which(covariate_table$Ethnicity=="Caucasian" & covariate_table$group=="venom"))
d2<-length(which(covariate_table$Ethnicity=="Caucasian" & covariate_table$group=="pollen"))
d3<-length(which(covariate_table$Ethnicity=="Caucasian" & covariate_table$group=="control"))
e1<-length(which(covariate_table$Ethnicity=="African" & covariate_table$group=="venom"))
e2<-length(which(covariate_table$Ethnicity=="African" & covariate_table$group=="pollen"))
e3<-length(which(covariate_table$Ethnicity=="African" & covariate_table$group=="control"))
f1<-length(which(covariate_table$Ethnicity=="Other" & covariate_table$group=="venom"))
f2<-length(which(covariate_table$Ethnicity=="Other" & covariate_table$group=="pollen"))
f3<-length(which(covariate_table$Ethnicity=="Other" & covariate_table$group=="control"))

Ethnicity<-rbind(c(d1,e1,f1),c(d2,e2,f2),c(d3,e3,f3))

# Fisher's Exact Test for Count Data
# 
# data:  Ethnicity
# p-value = 0.172
# alternative hypothesis: two.sided

