setwd("~/Feng_He_project/SysTACT_allergy_study/limma_withXY_all_modelA/exon_level_analysis")

load("~/Feng_He_project/SysTACT_allergy_study/read_summarization_exon/exon_counts.RData")

counts<-fc$counts

###################
#Remove bad sample#
###################
library(limma)
metadata<-strsplit2(colnames(counts),split="[.]")
metadata<-strsplit2(metadata[,9],split="_")
group<-vector(mode="character",length=187)
time_points<-vector(mode="character",length=187)
person<-vector(mode="character",length=187)
for (i in 1:187){
  group[i]<-substr(metadata[i,2],1,1)
  person[i]<-substr(metadata[i,2],1,3)
  time_points[i]<-substr(metadata[i,2],4,5)
}

#index P16 T3
index_P16_T3<-which(person=="P16" & time_points=="T3")

#remove P16 T3 from counts matrix
counts<-counts[,-index_P16_T3]

###############################
#make targets and design matrix
###############################
library(limma)
metadata<-strsplit2(colnames(counts),split="[.]")
metadata<-strsplit2(metadata[,9],split="_")
group<-vector(mode="character",length=187)
time_points<-vector(mode="character",length=187)
person<-vector(mode="character",length=187)
for (i in 1:187){
  group[i]<-substr(metadata[i,2],1,1)
  person[i]<-substr(metadata[i,2],1,3)
  time_points[i]<-substr(metadata[i,2],4,5)
}

time<-vector(mode="numeric",length=187)
time[which(time_points=="T0")]=0

time[which(group=="V" & time_points=="T1")]=0.3
time[which(group=="V" & time_points=="T2")]=1
time[which(group=="V" & time_points=="T3")]=7

time[which(group=="P" & time_points=="T1")]=1
time[which(group=="P" & time_points=="T2")]=14
time[which(group=="P" & time_points=="T3")]=42
time[which(group=="P" & time_points=="T4")]=84

time[which(group=="C" & time_points=="T1")]=0.3
time[which(group=="C" & time_points=="T2")]=1
time[which(group=="C" & time_points=="T3")]=7
time[which(group=="C" & time_points=="T4")]=14
time[which(group=="C" & time_points=="T5")]=42
time[which(group=="C" & time_points=="T6")]=84

metadata<-cbind(metadata[,1],metadata[,2],group,time_points,time,person)

colnames(metadata)[1:2]=c("batch","sample")

library(readxl)

X2019_07_19_SYS_T_Act_patient_demographics <- read_excel("~/Feng_He_project/SysTACT_allergy_study/confounders/2019.07.19 SYS-T-Act patient demographics.xlsx")
#remove persons without RNAseq samples, there are:
#V01,V02,V03,P05,P07
indices<-which(X2019_07_19_SYS_T_Act_patient_demographics$`SYS T ACT ID` %in% c("V01","V02","V03","P05","P07"))

covariate_table<-X2019_07_19_SYS_T_Act_patient_demographics[-indices,]
group<-vector(mode="character",length=39)
group[1:15]="venom"
group[16:29]="pollen"
group[30:39]="control"
covariate_table<-cbind(covariate_table,group)

age<-vector(mode="numeric",length=187)
bmi<-vector(mode="numeric",length=187)
ethnicity<-vector(mode="character",length=187)
smoking<-vector(mode="character",length=187)
culprit<-vector(mode="character",length=187)
gender<-vector(mode="character",length=187)

for (i in 1:187){
  age[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Age
  bmi[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$BMI
  ethnicity[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Ethnicity
  smoking[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Smoking
  culprit[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$`Culprit allergen`
  gender[i]<-covariate_table[which(covariate_table$`SYS T ACT ID`== metadata[i,6]),]$Sex
}

metadata<-cbind(metadata,age,bmi,ethnicity,smoking,culprit,gender)

Filename<-as.character(colnames(counts))
phenotype<-metadata[,3]
targets<-data.frame(Filename=Filename,phenotype=phenotype,
                    age=age,gender=gender,smoking=smoking,
                    time=time,person=person)
write.table(targets, file="targets.txt", sep = ",",row.names = FALSE)
# make a new group variable combining phenotype with time point
gr<-factor(paste(targets$phenotype,targets$time,sep="."))
#make design matrix with group as variable
design<-model.matrix(~0+gr+targets$age+targets$gender+targets$smoking)
colnames(design)[17:20]<-strsplit2(colnames(design)[17:20],split="[$]")[,2]

##########################
# Create a DGElist object
##########################
library("edgeR")
dge <- DGEList(counts=counts)

############################################################
# Remove rows that consistently have zero or very low counts
############################################################
keep <- filterByExpr(dge, design) 
dge <- dge[keep,,keep.lib.sizes=FALSE]

#############################
# TMM normalization
#############################
dge <- calcNormFactors(dge)

#############################
# Voom transform
#############################
library(limma)
v <- voom(dge, design, plot=TRUE)

data<-v$E

#gene_symbols for data (every gene has a gene symbol in gtf_df)
myPS<-rownames(v$E)
d<-length(myPS)
gene_names<-rep("NA",d)
library(rtracklayer)
gtf <- rtracklayer::import('gencode.v31.annotation.gtf')
gtf_df=as.data.frame(gtf)
for (i in 1:d){
  print(i)
  gene_names[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}

######################
# Limma analysis
######################
corfit<-duplicateCorrelation(data,design,block=targets$person)
fit<-lmFit(data,design,block=targets$person,correlation=corfit$consensus)
cm<-makeContrasts(PollenT0vsControlT0=grP.0-grC.0,
                  PollenT1vsControlT1=grP.1-grC.1,
                  PollenT2vsControlT2=grP.14-grC.14,
                  PollenT3vsControlT3=grP.42-grC.42,
                  PollenT4vsControlT4=grP.84-grC.84,
                  VenomT0vsControlT0=grV.0-grC.0,
                  VenomT1vsControlT1=grV.0.3-grC.0.3,
                  VenomT2vsControlT2=grV.1-grC.1,
                  VenomT3vsControlT3=grV.7-grC.7,
                  PollenT1vsPollenT0=grP.1-grP.0,
                  PollenT2vsPollenT0=grP.14-grP.0,
                  PollenT3vsPollenT0=grP.42-grP.0,
                  PollenT4vsPollenT0=grP.84-grP.0,
                  VenomT1vsVenomT0=grV.0.3-grV.0,
                  VenomT2vsVenomT0=grV.1-grV.0,
                  VenomT3vsVenomT0=grV.7-grV.0,
                  ControlT1vsControlT0=grC.0.3-grC.0,
                  ControlT2vsControlT0=grC.1-grC.0,
                  ControlT3vsControlT0=grC.7-grC.0,
                  ControlT4vsControlT0=grC.14-grC.0,
                  ControlT5vsControlT0=grC.42-grC.0,
                  ControlT6vsControlT0=grC.84-grC.0,
                  levels=design)

fit2 <- contrasts.fit(fit, cm) 
fit2<-eBayes(fit2)

table_PollenT0vsControlT0<-topTable(fit2,coef="PollenT0vsControlT0",n=Inf) #1
table_PollenT1vsControlT1<-topTable(fit2,coef="PollenT1vsControlT1",n=Inf) #2
table_PollenT2vsControlT2<-topTable(fit2,coef="PollenT2vsControlT2",n=Inf) #3
table_PollenT3vsControlT3<-topTable(fit2,coef="PollenT3vsControlT3",n=Inf) #4
table_PollenT4vsControlT4<-topTable(fit2,coef="PollenT4vsControlT4",n=Inf) #5
table_VenomT0vsControlT0<-topTable(fit2,coef="VenomT0vsControlT0",n=Inf) #6
table_VenomT1vsControlT1<-topTable(fit2,coef="VenomT1vsControlT1",n=Inf) #7
table_VenomT2vsControlT2<-topTable(fit2,coef="VenomT2vsControlT2",n=Inf) #8
table_VenomT3vsControlT3<-topTable(fit2,coef="VenomT3vsControlT3",n=Inf) #9
table_PollenT1vsPollenT0<-topTable(fit2,coef="PollenT1vsPollenT0",n=Inf) #10
table_PollenT2vsPollenT0<-topTable(fit2,coef="PollenT2vsPollenT0",n=Inf) #11
table_PollenT3vsPollenT0<-topTable(fit2,coef="PollenT3vsPollenT0",n=Inf) #12
table_PollenT4vsPollenT0<-topTable(fit2,coef="PollenT4vsPollenT0",n=Inf) #13
table_VenomT1vsVenomT0<-topTable(fit2,coef="VenomT1vsVenomT0",n=Inf) #14
table_VenomT2vsVenomT0<-topTable(fit2,coef="VenomT2vsVenomT0",n=Inf) #15
table_VenomT3vsVenomT0<-topTable(fit2,coef="VenomT3vsVenomT0",n=Inf) #16
table_ControlT1vsControlT0<-topTable(fit2,coef="ControlT1vsControlT0",n=Inf) #17
table_ControlT2vsControlT0<-topTable(fit2,coef="ControlT2vsControlT0",n=Inf) #18
table_ControlT3vsControlT0<-topTable(fit2,coef="ControlT3vsControlT0",n=Inf) #19
table_ControlT4vsControlT0<-topTable(fit2,coef="ControlT4vsControlT0",n=Inf) #20
table_ControlT5vsControlT0<-topTable(fit2,coef="ControlT5vsControlT0",n=Inf) #21
table_ControlT6vsControlT0<-topTable(fit2,coef="ControlT6vsControlT0",n=Inf) #22

#annotate tables
#1
myPS<-rownames(table_PollenT0vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT0vsControlT0<-cbind(table_PollenT0vsControlT0,gene_symbol)
write.table(table_PollenT0vsControlT0,file="table_PollenT0vsControlT0.txt",row.names = TRUE,col.names = NA)

#2
myPS<-rownames(table_PollenT1vsControlT1)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT1vsControlT1<-cbind(table_PollenT1vsControlT1,gene_symbol)
write.table(table_PollenT1vsControlT1,file="table_PollenT1vsControlT1.txt",row.names = TRUE,col.names = NA)

#3
myPS<-rownames(table_PollenT2vsControlT2)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT2vsControlT2<-cbind(table_PollenT2vsControlT2,gene_symbol)
write.table(table_PollenT2vsControlT2,file="table_PollenT2vsControlT2.txt",row.names = TRUE,col.names = NA)

#4
myPS<-rownames(table_PollenT3vsControlT3)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT3vsControlT3<-cbind(table_PollenT3vsControlT3,gene_symbol)
write.table(table_PollenT3vsControlT3,file="table_PollenT3vsControlT3.txt",row.names = TRUE,col.names = NA)

#5
myPS<-rownames(table_PollenT4vsControlT4)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT4vsControlT4<-cbind(table_PollenT4vsControlT4,gene_symbol)
write.table(table_PollenT4vsControlT4,file="table_PollenT4vsControlT4.txt",row.names = TRUE,col.names = NA)

#6
myPS<-rownames(table_VenomT0vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT0vsControlT0<-cbind(table_VenomT0vsControlT0,gene_symbol)
write.table(table_VenomT0vsControlT0,file="table_VenomT0vsControlT0.txt",row.names = TRUE,col.names = NA)

#7
myPS<-rownames(table_VenomT1vsControlT1)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT1vsControlT1<-cbind(table_VenomT1vsControlT1,gene_symbol)
write.table(table_VenomT1vsControlT1,file="table_VenomT1vsControlT1.txt",row.names = TRUE,col.names = NA)

#8
myPS<-rownames(table_VenomT2vsControlT2)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT2vsControlT2<-cbind(table_VenomT2vsControlT2,gene_symbol)
write.table(table_VenomT2vsControlT2,file="table_VenomT2vsControlT2.txt",row.names = TRUE,col.names = NA)

#9
myPS<-rownames(table_VenomT3vsControlT3)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT3vsControlT3<-cbind(table_VenomT3vsControlT3,gene_symbol)
write.table(table_VenomT3vsControlT3,file="table_VenomT3vsControlT3.txt",row.names = TRUE,col.names = NA)

#10
myPS<-rownames(table_PollenT1vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT1vsPollenT0<-cbind(table_PollenT1vsPollenT0,gene_symbol)
write.table(table_PollenT1vsPollenT0,file="table_PollenT1vsPollenT0.txt",row.names = TRUE,col.names = NA)

#11
myPS<-rownames(table_PollenT2vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT2vsPollenT0<-cbind(table_PollenT2vsPollenT0,gene_symbol)
write.table(table_PollenT2vsPollenT0,file="table_PollenT2vsPollenT0.txt",row.names = TRUE,col.names = NA)

#12
myPS<-rownames(table_PollenT3vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT3vsPollenT0<-cbind(table_PollenT3vsPollenT0,gene_symbol)
write.table(table_PollenT3vsPollenT0,file="table_PollenT3vsPollenT0.txt",row.names = TRUE,col.names = NA)

#13
myPS<-rownames(table_PollenT4vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_PollenT4vsPollenT0<-cbind(table_PollenT4vsPollenT0,gene_symbol)
write.table(table_PollenT4vsPollenT0,file="table_PollenT4vsPollenT0.txt",row.names = TRUE,col.names = NA)

#14
myPS<-rownames(table_VenomT1vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT1vsVenomT0<-cbind(table_VenomT1vsVenomT0,gene_symbol)
write.table(table_VenomT1vsVenomT0,file="table_VenomT1vsVenomT0.txt",row.names = TRUE,col.names = NA)

#15
myPS<-rownames(table_VenomT2vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT2vsVenomT0<-cbind(table_VenomT2vsVenomT0,gene_symbol)
write.table(table_VenomT2vsVenomT0,file="table_VenomT2vsVenomT0.txt",row.names = TRUE,col.names = NA)

#16
myPS<-rownames(table_VenomT3vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_VenomT3vsVenomT0<-cbind(table_VenomT3vsVenomT0,gene_symbol)
write.table(table_VenomT3vsVenomT0,file="table_VenomT3vsVenomT0.txt",row.names = TRUE,col.names = NA)

#17
myPS<-rownames(table_ControlT1vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT1vsControlT0<-cbind(table_ControlT1vsControlT0,gene_symbol)
write.table(table_ControlT1vsControlT0,file="table_ControlT1vsControlT0.txt",row.names = TRUE,col.names = NA)

#18
myPS<-rownames(table_ControlT2vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT2vsControlT0<-cbind(table_ControlT2vsControlT0,gene_symbol)
write.table(table_ControlT2vsControlT0,file="table_ControlT2vsControlT0.txt",row.names = TRUE,col.names = NA)

#19
myPS<-rownames(table_ControlT3vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT3vsControlT0<-cbind(table_ControlT3vsControlT0,gene_symbol)
write.table(table_ControlT3vsControlT0,file="table_ControlT3vsControlT0.txt",row.names = TRUE,col.names = NA)

#20
myPS<-rownames(table_ControlT4vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT4vsControlT0<-cbind(table_ControlT4vsControlT0,gene_symbol)
write.table(table_ControlT4vsControlT0,file="table_ControlT4vsControlT0.txt",row.names = TRUE,col.names = NA)

#21
myPS<-rownames(table_ControlT5vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT5vsControlT0<-cbind(table_ControlT5vsControlT0,gene_symbol)
write.table(table_ControlT5vsControlT0,file="table_ControlT5vsControlT0.txt",row.names = TRUE,col.names = NA)

#22
myPS<-rownames(table_ControlT6vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  gene_symbol[i]<-gtf_df[which(gtf_df$exon_id==myPS[i]),]$gene_name
}
table_ControlT6vsControlT0<-cbind(table_ControlT6vsControlT0,gene_symbol)
write.table(table_ControlT6vsControlT0,file="table_ControlT6vsControlT0.txt",row.names = TRUE,col.names = NA)

##################################################
# Tables of differentially expressed exons (DEE) #
##################################################
#1
DEE_table_PollenT0vsControlT0<-table_PollenT0vsControlT0[which(table_PollenT0vsControlT0$adj.P.Val<=0.05),]
DEE_PollenT0vsControlT0<-unique(as.character(DEE_table_PollenT0vsControlT0$gene_symbol))
#no DEE

#2
DEE_table_PollenT1vsControlT1<-table_PollenT1vsControlT1[which(table_PollenT1vsControlT1$adj.P.Val<=0.05),]
DEE_PollenT1vsControlT1<-unique(as.character(DEE_table_PollenT1vsControlT1$gene_symbol))
write.csv(DEE_table_PollenT1vsControlT1,file="DEE_PollenT1vsControlT1.csv")

#3
DEE_table_PollenT2vsControlT2<-table_PollenT2vsControlT2[which(table_PollenT2vsControlT2$adj.P.Val<=0.05),]
DEE_PollenT2vsControlT2<-unique(as.character(DEE_table_PollenT2vsControlT2$gene_symbol))
write.csv(DEE_table_PollenT2vsControlT2,file="DEE_PollenT2vsControlT2.csv")

#4
DEE_table_PollenT3vsControlT3<-table_PollenT3vsControlT3[which(table_PollenT3vsControlT3$adj.P.Val<=0.05),]
DEE_PollenT3vsControlT3<-unique(as.character(DEE_table_PollenT3vsControlT3$gene_symbol))
# no DEE

#5
DEE_table_PollenT4vsControlT4<-table_PollenT4vsControlT4[which(table_PollenT4vsControlT4$adj.P.Val<=0.05),]
DEE_PollenT4vsControlT4<-unique(as.character(DEE_table_PollenT4vsControlT4$gene_symbol))
write.csv(DEE_table_PollenT4vsControlT4,file="DEE_PollenT4vsControlT4.csv")

#6
DEE_table_VenomT0vsControlT0<-table_VenomT0vsControlT0[which(table_VenomT0vsControlT0$adj.P.Val<=0.05),]
DEE_VenomT0vsControlT0<-unique(as.character(DEE_table_VenomT0vsControlT0$gene_symbol))
write.csv(DEE_table_VenomT0vsControlT0,file="DEE_VenomT0vsControlT0.csv")

#7
DEE_table_VenomT1vsControlT1<-table_VenomT1vsControlT1[which(table_VenomT1vsControlT1$adj.P.Val<=0.05),]
DEE_VenomT1vsControlT1<-unique(as.character(DEE_table_VenomT1vsControlT1$gene_symbol))
write.csv(DEE_table_VenomT1vsControlT1,file="DEE_VenomT1vsControlT1.csv")

#8
DEE_table_VenomT2vsControlT2<-table_VenomT2vsControlT2[which(table_VenomT2vsControlT2$adj.P.Val<=0.05),]
DEE_VenomT2vsControlT2<-unique(as.character(DEE_table_VenomT2vsControlT2$gene_symbol))
write.csv(DEE_table_VenomT2vsControlT2,file="DEE_VenomT2vsControlT2.csv")

#9
DEE_table_VenomT3vsControlT3<-table_VenomT3vsControlT3[which(table_VenomT3vsControlT3$adj.P.Val<=0.05),]
DEE_VenomT3vsControlT3<-unique(as.character(DEE_table_VenomT3vsControlT3$gene_symbol))
write.csv(DEE_table_VenomT3vsControlT3,file="DEE_VenomT3vsControlT3.csv")

#10
DEE_table_PollenT1vsPollenT0<-table_PollenT1vsPollenT0[which(table_PollenT1vsPollenT0$adj.P.Val<=0.05),]
DEE_PollenT1vsPollenT0<-unique(as.character(DEE_table_PollenT1vsPollenT0$gene_symbol))
#no DEE

#11
DEE_table_PollenT2vsPollenT0<-table_PollenT2vsPollenT0[which(table_PollenT2vsPollenT0$adj.P.Val<=0.05),]
DEE_PollenT2vsPollenT0<-unique(as.character(DEE_table_PollenT2vsPollenT0$gene_symbol))
write.csv(DEE_table_PollenT2vsPollenT0,file="DEE_PollenT2vsPollenT0.csv")

#12
DEE_table_PollenT3vsPollenT0<-table_PollenT3vsPollenT0[which(table_PollenT3vsPollenT0$adj.P.Val<=0.05),]
DEE_PollenT3vsPollenT0<-unique(as.character(DEE_table_PollenT3vsPollenT0$gene_symbol))
write.csv(DEE_table_PollenT3vsPollenT0,file="DEE_PollenT3vsPollenT0.csv")

#13
DEE_table_PollenT4vsPollenT0<-table_PollenT4vsPollenT0[which(table_PollenT4vsPollenT0$adj.P.Val<=0.05),]
DEE_PollenT4vsPollenT0<-unique(as.character(DEE_table_PollenT4vsPollenT0$gene_symbol))
write.csv(DEE_table_PollenT4vsPollenT0,file="DEE_PollenT4vsPollenT0.csv")

#14
DEE_table_VenomT1vsVenomT0<-table_VenomT1vsVenomT0[which(table_VenomT1vsVenomT0$adj.P.Val<=0.05),]
DEE_VenomT1vsVenomT0<-unique(as.character(DEE_table_VenomT1vsVenomT0$gene_symbol))
write.csv(DEE_table_VenomT1vsVenomT0,file="DEE_VenomT1vsVenomT0.csv")

#15
DEE_table_VenomT2vsVenomT0<-table_VenomT2vsVenomT0[which(table_VenomT2vsVenomT0$adj.P.Val<=0.05),]
DEE_VenomT2vsVenomT0<-unique(as.character(DEE_table_VenomT2vsVenomT0$gene_symbol))
#no DEE

#16
DEE_table_VenomT3vsVenomT0<-table_VenomT3vsVenomT0[which(table_VenomT3vsVenomT0$adj.P.Val<=0.05),]
DEE_VenomT3vsVenomT0<-unique(as.character(DEE_table_VenomT3vsVenomT0$gene_symbol))
write.csv(DEE_table_VenomT3vsVenomT0,file="DEE_VenomT3vsVenomT0.csv")

#17
DEE_table_ControlT1vsControlT0<-table_ControlT1vsControlT0[which(table_ControlT1vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT1vsControlT0<-unique(as.character(DEE_table_ControlT1vsControlT0$gene_symbol))
#no DEE

#18
DEE_table_ControlT2vsControlT0<-table_ControlT2vsControlT0[which(table_ControlT2vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT2vsControlT0<-unique(as.character(DEE_table_ControlT2vsControlT0$gene_symbol))
write.csv(DEE_table_ControlT2vsControlT0,"DEE_ControlT2vsControlT0.csv")

#19
DEE_table_ControlT3vsControlT0<-table_ControlT3vsControlT0[which(table_ControlT3vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT3vsControlT0<-unique(as.character(DEE_table_ControlT3vsControlT0$gene_symbol))
write.csv(DEE_table_ControlT3vsControlT0,"DEE_ControlT3vsControlT0.csv")

#20
DEE_table_ControlT4vsControlT0<-table_ControlT4vsControlT0[which(table_ControlT4vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT4vsControlT0<-unique(as.character(DEE_table_ControlT4vsControlT0$gene_symbol))
write.csv(DEE_table_ControlT4vsControlT0,"DEE_ControlT4vsControlT0.csv")

#21
DEE_table_ControlT5vsControlT0<-table_ControlT5vsControlT0[which(table_ControlT5vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT5vsControlT0<-unique(as.character(DEE_table_ControlT5vsControlT0$gene_symbol))
#no DEE

#22
DEE_table_ControlT6vsControlT0<-table_ControlT6vsControlT0[which(table_ControlT6vsControlT0$adj.P.Val<=0.05),]
DEE_ControlT6vsControlT0<-unique(as.character(DEE_table_ControlT6vsControlT0$gene_symbol))
write.csv(DEE_table_ControlT6vsControlT0,"DEE_ControlT6vsControlT0.csv")

##############################################
# genes with exons with opposing alterations #
##############################################
# 1
opp_PollenT0vsControlT0<-character(0)
sign_opp_PollenT0vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT0vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT0vsControlT0$gene_symbol==gn[i])
  
  #all opposing alterations
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT0vsControlT0[index1,]$logFC)))==2){
      opp_PollenT0vsControlT0<-c(opp_PollenT0vsControlT0,gn[i])
    }
  }
  
  #significant opposing alterations
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT0vsControlT0[index2,]$logFC)))==2){
      sign_opp_PollenT0vsControlT0<-c(sign_opp_PollenT0vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#2
opp_PollenT1vsControlT1<-character(0)
sign_opp_PollenT1vsControlT1<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT1vsControlT1$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT1vsControlT1$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT1vsControlT1[index1,]$logFC)))==2){
      opp_PollenT1vsControlT1<-c(opp_PollenT1vsControlT1,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT1vsControlT1[index2,]$logFC)))==2){
      sign_opp_PollenT1vsControlT1<-c(sign_opp_PollenT1vsControlT1,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#3
opp_PollenT2vsControlT2<-character(0)
sign_opp_PollenT2vsControlT2<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT2vsControlT2$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT2vsControlT2$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT2vsControlT2[index1,]$logFC)))==2){
      opp_PollenT2vsControlT2<-c(opp_PollenT2vsControlT2,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT2vsControlT2[index2,]$logFC)))==2){
      sign_opp_PollenT2vsControlT2<-c(sign_opp_PollenT2vsControlT2,gn[i])
    }
  }
}
# genes with significant opposing alterations: NBPF20 and NBPF14

#4
opp_PollenT3vsControlT3<-character(0)
sign_opp_PollenT3vsControlT3<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT3vsControlT3$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT3vsControlT3$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT3vsControlT3[index1,]$logFC)))==2){
      opp_PollenT3vsControlT3<-c(opp_PollenT3vsControlT3,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT3vsControlT3[index2,]$logFC)))==2){
      sign_opp_PollenT3vsControlT3<-c(sign_opp_PollenT3vsControlT3,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#5
opp_PollenT4vsControlT4<-character(0)
sign_opp_PollenT4vsControlT4<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT4vsControlT4$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT4vsControlT4$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT4vsControlT4[index1,]$logFC)))==2){
      opp_PollenT4vsControlT4<-c(opp_PollenT4vsControlT4,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT4vsControlT4[index2,]$logFC)))==2){
      sign_opp_PollenT4vsControlT4<-c(sign_opp_PollenT4vsControlT4,gn[i])
    }
  }
}
# genes with significant opposing alterations: NBPF20

#6
opp_VenomT0vsControlT0<-character(0)
sign_opp_VenomT0vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT0vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT0vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT0vsControlT0[index1,]$logFC)))==2){
      opp_VenomT0vsControlT0<-c(opp_VenomT0vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT0vsControlT0[index2,]$logFC)))==2){
      sign_opp_VenomT0vsControlT0<-c(sign_opp_VenomT0vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#7
opp_VenomT1vsControlT1<-character(0)
sign_opp_VenomT1vsControlT1<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT1vsControlT1$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT1vsControlT1$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT1vsControlT1[index1,]$logFC)))==2){
      opp_VenomT1vsControlT1<-c(opp_VenomT1vsControlT1,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT1vsControlT1[index2,]$logFC)))==2){
      sign_opp_VenomT1vsControlT1<-c(sign_opp_VenomT1vsControlT1,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#8
opp_VenomT2vsControlT2<-character(0)
sign_opp_VenomT2vsControlT2<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT2vsControlT2$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT2vsControlT2$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT2vsControlT2[index1,]$logFC)))==2){
      opp_VenomT2vsControlT2<-c(opp_VenomT2vsControlT2,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT2vsControlT2[index2,]$logFC)))==2){
      sign_opp_VenomT2vsControlT2<-c(sign_opp_VenomT2vsControlT2,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#9
opp_VenomT3vsControlT3<-character(0)
sign_opp_VenomT3vsControlT3<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT3vsControlT3$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT3vsControlT3$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT3vsControlT3[index1,]$logFC)))==2){
      opp_VenomT3vsControlT3<-c(opp_VenomT3vsControlT3,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT3vsControlT3[index2,]$logFC)))==2){
      sign_opp_VenomT3vsControlT3<-c(sign_opp_VenomT3vsControlT3,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#10
opp_PollenT1vsPollenT0<-character(0)
sign_opp_PollenT1vsPollenT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT1vsPollenT0$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT1vsPollenT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT1vsPollenT0[index1,]$logFC)))==2){
      opp_PollenT1vsPollenT0<-c(opp_PollenT1vsPollenT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT1vsPollenT0[index2,]$logFC)))==2){
      sign_opp_PollenT1vsPollenT0<-c(sign_opp_PollenT1vsPollenT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#11
opp_PollenT2vsPollenT0<-character(0)
sign_opp_PollenT2vsPollenT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT2vsPollenT0$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT2vsPollenT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT2vsPollenT0[index1,]$logFC)))==2){
      opp_PollenT2vsPollenT0<-c(opp_PollenT2vsPollenT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT2vsPollenT0[index2,]$logFC)))==2){
      sign_opp_PollenT2vsPollenT0<-c(sign_opp_PollenT2vsPollenT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#12
opp_PollenT3vsPollenT0<-character(0)
sign_opp_PollenT3vsPollenT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT3vsPollenT0$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT3vsPollenT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT3vsPollenT0[index1,]$logFC)))==2){
      opp_PollenT3vsPollenT0<-c(opp_PollenT3vsPollenT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT3vsPollenT0[index2,]$logFC)))==2){
      sign_opp_PollenT3vsPollenT0<-c(sign_opp_PollenT3vsPollenT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#13
opp_PollenT4vsPollenT0<-character(0)
sign_opp_PollenT4vsPollenT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_PollenT4vsPollenT0$gene_symbol==gn[i])
  index2<-which(DEE_table_PollenT4vsPollenT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_PollenT4vsPollenT0[index1,]$logFC)))==2){
      opp_PollenT4vsPollenT0<-c(opp_PollenT4vsPollenT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_PollenT4vsPollenT0[index2,]$logFC)))==2){
      sign_opp_PollenT4vsPollenT0<-c(sign_opp_PollenT4vsPollenT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#14
opp_VenomT1vsVenomT0<-character(0)
sign_opp_VenomT1vsVenomT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT1vsVenomT0$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT1vsVenomT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT1vsVenomT0[index1,]$logFC)))==2){
      opp_VenomT1vsVenomT0<-c(opp_VenomT1vsVenomT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT1vsVenomT0[index2,]$logFC)))==2){
      sign_opp_VenomT1vsVenomT0<-c(sign_opp_VenomT1vsVenomT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#15
opp_VenomT2vsVenomT0<-character(0)
sign_opp_VenomT2vsVenomT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT2vsVenomT0$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT2vsVenomT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT2vsVenomT0[index1,]$logFC)))==2){
      opp_VenomT2vsVenomT0<-c(opp_VenomT2vsVenomT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT2vsVenomT0[index2,]$logFC)))==2){
      sign_opp_VenomT2vsVenomT0<-c(sign_opp_VenomT2vsVenomT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#16
opp_VenomT3vsVenomT0<-character(0)
sign_opp_VenomT3vsVenomT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_VenomT3vsVenomT0$gene_symbol==gn[i])
  index2<-which(DEE_table_VenomT3vsVenomT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_VenomT3vsVenomT0[index1,]$logFC)))==2){
      opp_VenomT3vsVenomT0<-c(opp_VenomT3vsVenomT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_VenomT3vsVenomT0[index2,]$logFC)))==2){
      sign_opp_VenomT3vsVenomT0<-c(sign_opp_VenomT3vsVenomT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#17
opp_ControlT1vsControlT0<-character(0)
sign_opp_ControlT1vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT1vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT1vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT1vsControlT0[index1,]$logFC)))==2){
      opp_ControlT1vsControlT0<-c(opp_ControlT1vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT1vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT1vsControlT0<-c(sign_opp_ControlT1vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#18
opp_ControlT2vsControlT0<-character(0)
sign_opp_ControlT2vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT2vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT2vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT2vsControlT0[index1,]$logFC)))==2){
      opp_ControlT2vsControlT0<-c(opp_ControlT2vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT2vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT2vsControlT0<-c(sign_opp_ControlT2vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#19
opp_ControlT3vsControlT0<-character(0)
sign_opp_ControlT3vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT3vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT3vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT3vsControlT0[index1,]$logFC)))==2){
      opp_ControlT3vsControlT0<-c(opp_ControlT3vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT3vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT3vsControlT0<-c(sign_opp_ControlT3vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#20
opp_ControlT4vsControlT0<-character(0)
sign_opp_ControlT4vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT4vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT4vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT4vsControlT0[index1,]$logFC)))==2){
      opp_ControlT4vsControlT0<-c(opp_ControlT4vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT4vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT4vsControlT0<-c(sign_opp_ControlT4vsControlT0,gn[i])
    }
  }
}
# genes with significant opposing alterations: NBPF20 and NBPF14 

#21
opp_ControlT5vsControlT0<-character(0)
sign_opp_ControlT5vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT5vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT5vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT5vsControlT0[index1,]$logFC)))==2){
      opp_ControlT5vsControlT0<-c(opp_ControlT5vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT5vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT5vsControlT0<-c(sign_opp_ControlT5vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations

#22
opp_ControlT6vsControlT0<-character(0)
sign_opp_ControlT6vsControlT0<-character(0)
d<-length(unique(gene_names))
gn<-unique(gene_names)
for (i in 1:d){
  print(i)
  index1<-which(table_ControlT6vsControlT0$gene_symbol==gn[i])
  index2<-which(DEE_table_ControlT6vsControlT0$gene_symbol==gn[i])
  
  if (length(index1>1)){
    if (length(unique(sign(table_ControlT6vsControlT0[index1,]$logFC)))==2){
      opp_ControlT6vsControlT0<-c(opp_ControlT6vsControlT0,gn[i])
    }
  }
  
  if (length(index2>1)){
    if (length(unique(sign(DEE_table_ControlT6vsControlT0[index2,]$logFC)))==2){
      sign_opp_ControlT6vsControlT0<-c(sign_opp_ControlT6vsControlT0,gn[i])
    }
  }
}
# no genes with significant opposing alterations
