setwd("~/Feng_He_project/SysTACT_allergy_study/limma_withXY_all_model2")

#load workspace from outlier detection
load("~/Feng_He_project/SysTACT_allergy_study/outlier_dectection_v2/workspace_outliers.RData")

#index P16 T3
index_P16_T3<-which(person=="P16" & time_points=="T3")

#remove P16 T3 from counts matrix
counts<-counts[,-index_P16_T3]

###############################
#make targets and design matrix
###############################
library(limma)
time<-time[-index_P16_T3]
Filename<-as.character(colnames(counts))
phenotype<-phenotype[-index_P16_T3]
age<-age[-index_P16_T3]
gender<-gender[-index_P16_T3]
smoking<-smoking[-index_P16_T3]
person<-person[-index_P16_T3]
targets<-data.frame(Filename=Filename,
                    phenotype=phenotype,
                    age=age,
                    gender=gender,
                    smoking=smoking,
                    time=time,
                    person=person)
write.table(targets,file="targets.txt",sep = ",",row.names = FALSE)
# make a new group variable combining phenotype with time point
gr<-factor(paste(targets$phenotype,targets$time,sep="."))
#make new design matrix with group as variable
design<-model.matrix(~0+gr+targets$age+targets$gender+targets$smoking)
colnames(design)[17:20]<-strsplit2(colnames(design)[17:20],split="[$]")[,2]

##########################
# Create a DGElist object
##########################
library("edgeR")
dge <- DGEList(counts=counts)

############################################################
# Remove rows that consistently have zero or very low counts
############################################################
keep <- filterByExpr(dge, design) 
dge <- dge[keep,,keep.lib.sizes=FALSE]

#############################
# TMM normalization
#############################
dge <- calcNormFactors(dge)

#############################
# Voom transform
#############################
library(limma)
v <- voom(dge, design, plot=TRUE)

data<-v$E

#gene_symbols for data
library("org.Hs.eg.db")
library("annotationTools")
x <- org.Hs.egSYMBOL 

myPS<-rownames(v$E)
d<-length(myPS)
gene_names<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_names[i] <- test}
}

######################
# Limma analysis
######################
corfit<-duplicateCorrelation(data,design,block=targets$person)
fit<-lmFit(data,design,block=targets$person,correlation=corfit$consensus)
cm<-makeContrasts(PollenT0vsControlT0=grP.0-grC.0,
                  PollenT1vsControlT1=grP.1-grC.1,
                  PollenT2vsControlT2=grP.14-grC.14,
                  PollenT3vsControlT3=grP.42-grC.42,
                  PollenT4vsControlT4=grP.84-grC.84,
                  VenomT0vsControlT0=grV.0-grC.0,
                  VenomT1vsControlT1=grV.0.3-grC.0.3,
                  VenomT2vsControlT2=grV.1-grC.1,
                  VenomT3vsControlT3=grV.7-grC.7,
                  PollenT1vsPollenT0=grP.1-grP.0,
                  PollenT2vsPollenT0=grP.14-grP.0,
                  PollenT3vsPollenT0=grP.42-grP.0,
                  PollenT4vsPollenT0=grP.84-grP.0,
                  VenomT1vsVenomT0=grV.0.3-grV.0,
                  VenomT2vsVenomT0=grV.1-grV.0,
                  VenomT3vsVenomT0=grV.7-grV.0,
                  ControlT1vsControlT0=grC.0.3-grC.0,
                  ControlT2vsControlT0=grC.1-grC.0,
                  ControlT3vsControlT0=grC.7-grC.0,
                  ControlT4vsControlT0=grC.14-grC.0,
                  ControlT5vsControlT0=grC.42-grC.0,
                  ControlT6vsControlT0=grC.84-grC.0,
                  levels=design)

fit2 <- contrasts.fit(fit, cm) 
fit2<-eBayes(fit2)

table_PollenT0vsControlT0<-topTable(fit2,coef="PollenT0vsControlT0",n=Inf) #1
table_PollenT1vsControlT1<-topTable(fit2,coef="PollenT1vsControlT1",n=Inf) #2
table_PollenT2vsControlT2<-topTable(fit2,coef="PollenT2vsControlT2",n=Inf) #3
table_PollenT3vsControlT3<-topTable(fit2,coef="PollenT3vsControlT3",n=Inf) #4
table_PollenT4vsControlT4<-topTable(fit2,coef="PollenT4vsControlT4",n=Inf) #5
table_VenomT0vsControlT0<-topTable(fit2,coef="VenomT0vsControlT0",n=Inf) #6
table_VenomT1vsControlT1<-topTable(fit2,coef="VenomT1vsControlT1",n=Inf) #7
table_VenomT2vsControlT2<-topTable(fit2,coef="VenomT2vsControlT2",n=Inf) #8
table_VenomT3vsControlT3<-topTable(fit2,coef="VenomT3vsControlT3",n=Inf) #9
table_PollenT1vsPollenT0<-topTable(fit2,coef="PollenT1vsPollenT0",n=Inf) #10
table_PollenT2vsPollenT0<-topTable(fit2,coef="PollenT2vsPollenT0",n=Inf) #11
table_PollenT3vsPollenT0<-topTable(fit2,coef="PollenT3vsPollenT0",n=Inf) #12
table_PollenT4vsPollenT0<-topTable(fit2,coef="PollenT4vsPollenT0",n=Inf) #13
table_VenomT1vsVenomT0<-topTable(fit2,coef="VenomT1vsVenomT0",n=Inf) #14
table_VenomT2vsVenomT0<-topTable(fit2,coef="VenomT2vsVenomT0",n=Inf) #15
table_VenomT3vsVenomT0<-topTable(fit2,coef="VenomT3vsVenomT0",n=Inf) #16
table_ControlT1vsControlT0<-topTable(fit2,coef="ControlT1vsControlT0",n=Inf) #17
table_ControlT2vsControlT0<-topTable(fit2,coef="ControlT2vsControlT0",n=Inf) #18
table_ControlT3vsControlT0<-topTable(fit2,coef="ControlT3vsControlT0",n=Inf) #19
table_ControlT4vsControlT0<-topTable(fit2,coef="ControlT4vsControlT0",n=Inf) #20
table_ControlT5vsControlT0<-topTable(fit2,coef="ControlT5vsControlT0",n=Inf) #21
table_ControlT6vsControlT0<-topTable(fit2,coef="ControlT6vsControlT0",n=Inf) #22

#annotate tables
#1
myPS<-rownames(table_PollenT0vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT0vsControlT0<-cbind(table_PollenT0vsControlT0,gene_symbol)
write.table(table_PollenT0vsControlT0,file="table_PollenT0vsControlT0.txt",row.names = TRUE,col.names = NA)

#2
myPS<-rownames(table_PollenT1vsControlT1)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT1vsControlT1<-cbind(table_PollenT1vsControlT1,gene_symbol)
write.table(table_PollenT1vsControlT1,file="table_PollenT1vsControlT1.txt",row.names = TRUE,col.names = NA)

#3
myPS<-rownames(table_PollenT2vsControlT2)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT2vsControlT2<-cbind(table_PollenT2vsControlT2,gene_symbol)
write.table(table_PollenT2vsControlT2,file="table_PollenT2vsControlT2.txt",row.names = TRUE,col.names = NA)

#4
myPS<-rownames(table_PollenT3vsControlT3)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT3vsControlT3<-cbind(table_PollenT3vsControlT3,gene_symbol)
write.table(table_PollenT3vsControlT3,file="table_PollenT3vsControlT3.txt",row.names = TRUE,col.names = NA)

#5
myPS<-rownames(table_PollenT4vsControlT4)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT4vsControlT4<-cbind(table_PollenT4vsControlT4,gene_symbol)
write.table(table_PollenT4vsControlT4,file="table_PollenT4vsControlT4.txt",row.names = TRUE,col.names = NA)

#6
myPS<-rownames(table_VenomT0vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT0vsControlT0<-cbind(table_VenomT0vsControlT0,gene_symbol)
write.table(table_VenomT0vsControlT0,file="table_VenomT0vsControlT0.txt",row.names = TRUE,col.names = NA)

#7
myPS<-rownames(table_VenomT1vsControlT1)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT1vsControlT1<-cbind(table_VenomT1vsControlT1,gene_symbol)
write.table(table_VenomT1vsControlT1,file="table_VenomT1vsControlT1.txt",row.names = TRUE,col.names = NA)

#8
myPS<-rownames(table_VenomT2vsControlT2)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT2vsControlT2<-cbind(table_VenomT2vsControlT2,gene_symbol)
write.table(table_VenomT2vsControlT2,file="table_VenomT2vsControlT2.txt",row.names = TRUE,col.names = NA)

#9
myPS<-rownames(table_VenomT3vsControlT3)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT3vsControlT3<-cbind(table_VenomT3vsControlT3,gene_symbol)
write.table(table_VenomT3vsControlT3,file="table_VenomT3vsControlT3.txt",row.names = TRUE,col.names = NA)

#10
myPS<-rownames(table_PollenT1vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT1vsPollenT0<-cbind(table_PollenT1vsPollenT0,gene_symbol)
write.table(table_PollenT1vsPollenT0,file="table_PollenT1vsPollenT0.txt",row.names = TRUE,col.names = NA)

#11
myPS<-rownames(table_PollenT2vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT2vsPollenT0<-cbind(table_PollenT2vsPollenT0,gene_symbol)
write.table(table_PollenT2vsPollenT0,file="table_PollenT2vsPollenT0.txt",row.names = TRUE,col.names = NA)

#12
myPS<-rownames(table_PollenT3vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT3vsPollenT0<-cbind(table_PollenT3vsPollenT0,gene_symbol)
write.table(table_PollenT3vsPollenT0,file="table_PollenT3vsPollenT0.txt",row.names = TRUE,col.names = NA)

#13
myPS<-rownames(table_PollenT4vsPollenT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT4vsPollenT0<-cbind(table_PollenT4vsPollenT0,gene_symbol)
write.table(table_PollenT4vsPollenT0,file="table_PollenT4vsPollenT0.txt",row.names = TRUE,col.names = NA)

#14
myPS<-rownames(table_VenomT1vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT1vsVenomT0<-cbind(table_VenomT1vsVenomT0,gene_symbol)
write.table(table_VenomT1vsVenomT0,file="table_VenomT1vsVenomT0.txt",row.names = TRUE,col.names = NA)

#15
myPS<-rownames(table_VenomT2vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT2vsVenomT0<-cbind(table_VenomT2vsVenomT0,gene_symbol)
write.table(table_VenomT2vsVenomT0,file="table_VenomT2vsVenomT0.txt",row.names = TRUE,col.names = NA)

#16
myPS<-rownames(table_VenomT3vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_VenomT3vsVenomT0<-cbind(table_VenomT3vsVenomT0,gene_symbol)
write.table(table_VenomT3vsVenomT0,file="table_VenomT3vsVenomT0.txt",row.names = TRUE,col.names = NA)

#17
myPS<-rownames(table_ControlT1vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT1vsControlT0<-cbind(table_ControlT1vsControlT0,gene_symbol)
write.table(table_ControlT1vsControlT0,file="table_ControlT1vsControlT0.txt",row.names = TRUE,col.names = NA)

#18
myPS<-rownames(table_ControlT2vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT2vsControlT0<-cbind(table_ControlT2vsControlT0,gene_symbol)
write.table(table_ControlT2vsControlT0,file="table_ControlT2vsControlT0.txt",row.names = TRUE,col.names = NA)

#19
myPS<-rownames(table_ControlT3vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT3vsControlT0<-cbind(table_ControlT3vsControlT0,gene_symbol)
write.table(table_ControlT3vsControlT0,file="table_ControlT3vsControlT0.txt",row.names = TRUE,col.names = NA)

#20
myPS<-rownames(table_ControlT4vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT4vsControlT0<-cbind(table_ControlT4vsControlT0,gene_symbol)
write.table(table_ControlT4vsControlT0,file="table_ControlT4vsControlT0.txt",row.names = TRUE,col.names = NA)

#21
myPS<-rownames(table_ControlT5vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT5vsControlT0<-cbind(table_ControlT5vsControlT0,gene_symbol)
write.table(table_ControlT5vsControlT0,file="table_ControlT5vsControlT0.txt",row.names = TRUE,col.names = NA)

#22
myPS<-rownames(table_ControlT6vsControlT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_ControlT6vsControlT0<-cbind(table_ControlT6vsControlT0,gene_symbol)
write.table(table_ControlT6vsControlT0,file="table_ControlT6vsControlT0.txt",row.names = TRUE,col.names = NA)

