setwd("~/Feng_He_project/SysTACT_allergy_study/limma_withXY_all_modelA")

#load workspace from outlier detection
load("~/Feng_He_project/SysTACT_allergy_study/outlier_dectection_v2/workspace_outliers.RData")

#index P16 T3
index_P16_T3<-which(person=="P16" & time_points=="T3")

#remove P16 T3 from counts matrix
counts<-counts[,-index_P16_T3]

###############################
#make targets and design matrix
###############################
library(limma)
time<-time[-index_P16_T3]
Filename<-as.character(colnames(counts))
phenotype<-phenotype[-index_P16_T3]
age<-age[-index_P16_T3]
gender<-gender[-index_P16_T3]
smoking<-smoking[-index_P16_T3]
person<-person[-index_P16_T3]
targets<-data.frame(Filename=Filename,
                    phenotype=phenotype,
                    age=age,
                    gender=gender,
                    smoking=smoking,
                    time=time,
                    person=person)
write.table(targets,file="targets.txt",sep = ",",row.names = FALSE)
# make a new group variable combining phenotype with time point
gr<-factor(paste(targets$phenotype,targets$time,sep="."))
#make new design matrix with group as variable
design<-model.matrix(~0+gr+targets$age+targets$gender+targets$smoking)
colnames(design)[17:20]<-strsplit2(colnames(design)[17:20],split="[$]")[,2]

##########################
# Create a DGElist object
##########################
library("edgeR")
dge <- DGEList(counts=counts)

############################################################
# Remove rows that consistently have zero or very low counts
############################################################
keep <- filterByExpr(dge, design) 
dge <- dge[keep,,keep.lib.sizes=FALSE]

#############################
# TMM normalization
#############################
dge <- calcNormFactors(dge)

#############################
# Voom transform
#############################
library(limma)
v <- voom(dge, design, plot=TRUE)

data<-v$E

#gene_symbols for data
library("org.Hs.eg.db")
library("annotationTools")
x <- org.Hs.egSYMBOL 

myPS<-rownames(v$E)
d<-length(myPS)
gene_names<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_names[i] <- test}
}

######################
# Limma analysis
######################
corfit<-duplicateCorrelation(data,design,block=targets$person)
fit<-lmFit(data,design,block=targets$person,correlation=corfit$consensus)
cm<-makeContrasts(PollenT0vsVenomT0=grP.0-grV.0,levels=design)
fit2<-contrasts.fit(fit,cm)
fit2<-eBayes(fit2)

table_PollenT0vsVenomT0<-topTable(fit2,coef="PollenT0vsVenomT0",n=Inf)

#annotate table
myPS<-rownames(table_PollenT0vsVenomT0)
d<-length(myPS)
gene_symbol<-rep("NA",d)
for (i in 1:d){
  print(i)
  test<-try(listToCharacterVector(as.list(x[myPS[i]])),silent=TRUE)
  if (is.null(attr(test,"class"))==TRUE){gene_symbol[i] <- test}
}
table_PollenT0vsVenomT0<-cbind(table_PollenT0vsVenomT0,gene_symbol)
write.table(table_PollenT0vsVenomT0,file="table_PollenT0vsVenomT0.txt",row.names = TRUE,col.names = NA)



